OC.L10N.register(
    "recommendations",
    {
    "Recently commented" : "Nyligen kommenterade",
    "Recently edited" : "Nyligen redigerad",
    "Recently shared" : "Nyligen delade",
    "Recommendations" : "Rekommendationer",
    "Shows recommended files" : "Visar rekommenderade filer",
    "Shows recommended files for quick access of files and folders with recent activity" : "Visar rekommenderade filer för snabb åtkomst av filer och mappar med senast aktivitet",
    "Enabled" : "Aktiverad"
},
"nplurals=2; plural=(n != 1);");
